==> OLIN_1.30.0.tgz: OLIN/doc/OLIN.R <==
###################################################
### chunk number 1: 
###################################################
#line 54 "OLIN.Rnw"
  library(OLIN) 


###################################################
### chunk number 2:  eval=FALSE
###################################################
## #line 89 "OLIN.Rnw"
##   data(sw)
##   fgbg.visu(sw[,3])


###################################################
### chunk number 3: 
###################################################
#line 96 "OLIN.Rnw"
  data(sw)
  fgbg.visu(sw[,3])


###################################################
### chunk number 4:  eval=FALSE
###################################################
## #line 113 "OLIN.Rnw"
## plot(maA(sw[,3]),maM(sw[,3]),xlab="A",ylab="M")


###################################################
### chunk number 5: 
###################################################
#line 120 "OLIN.Rnw"
par(cex.lab=0.6)
plot(maA(sw[,3]),maM(sw[,3]),xlab="A",ylab="M",pch='.')


###################################################
### chunk number 6:  eval=FALSE
###################################################
## #line 130 "OLIN.Rnw"
## mxy.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
##                  Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### chunk number 7: 
###################################################
#line 138 "OLIN.Rnw"
mxy.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
                 Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### chunk number 8:  eval=FALSE
###################################################
## #line 153 "OLIN.Rnw"
## data(sw.xy)
## mxy.abs.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### chunk number 9: 
###################################################
#line 161 "OLIN.Rnw"
data(sw.xy)
mxy.abs.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))



###################################################
### chunk number 10:  eval=FALSE
###################################################
## #line 180 "OLIN.Rnw"
## data(sw.xy)
## mxy2.plot(maM(sw)[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],
##           Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))
## 


###################################################
### chunk number 11: 
###################################################
#line 190 "OLIN.Rnw"
data(sw.xy)
mxy2.plot(maM(sw)[,3],X=sw.xy$X[,3],sw.xy$Y[,3],
          Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))



###################################################
### chunk number 12: 
###################################################
#line 303 "OLIN.Rnw"
norm.olin <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3])


###################################################
### chunk number 13:  eval=FALSE
###################################################
## #line 315 "OLIN.Rnw"
## plot(maA(norm.olin),maM(norm.olin),main="OLIN",pch=".")
## 
## mxy.plot(maM(norm.olin),Ngc=maNgc(norm.olin),Ngr=maNgr(norm.olin),
##                 Nsc=maNsc(norm.olin),Nsr=maNsr(norm.olin),main="OLIN")
## 


###################################################
### chunk number 14: 
###################################################
#line 328 "OLIN.Rnw"
par(cex.main=0.8)
par(cex.lab =0.8)
plot(maA(norm.olin),maM(norm.olin),main="OLIN",pch=".")


###################################################
### chunk number 15: 
###################################################
#line 342 "OLIN.Rnw"
 
 mxy.plot(maM(norm.olin),Ngc=maNgc(norm.olin),Ngr=maNgr(norm.olin),
                Nsc=maNsc(norm.olin),Nsr=maNsr(norm.olin),main="OLIN")


###################################################
### chunk number 16:  eval=FALSE
###################################################
## #line 357 "OLIN.Rnw"
## norm.olin.1 <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## norm.olin.2 <- olin(norm.olin.1,X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## norm.olin.3 <- olin(norm.olin.2,X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## 
## M <- cbind(maM(sw)[,3],maM(norm.olin.1),maM(norm.olin.2),maM(norm.olin.3))
## pairs(M,labels= c("raw","1.Iter.","2.Iter.","3.Iter."))


###################################################
### chunk number 17: 
###################################################
#line 385 "OLIN.Rnw"
norm.oslin <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],alpha=c(0.1,1,0.1),OSLIN=TRUE)


###################################################
### chunk number 18:  eval=FALSE
###################################################
## #line 396 "OLIN.Rnw"
## plot(maA(norm.oslin),maM(norm.oslin),main="OSLIN",pch=".")
## 
## mxy.plot(maM(norm.oslin),Ngc=maNgc(norm.oslin),Ngr=maNgr(norm.oslin),
##                 Nsc=maNsc(norm.oslin),Nsr=maNsr(norm.oslin),main="OSLIN")
## 


###################################################
### chunk number 19: 
###################################################
#line 409 "OLIN.Rnw"
par(cex.main=0.8)
par(cex.lab =0.8)
plot(maA(norm.oslin),maM(norm.oslin),main="OSLIN",pch=".")


###################################################
### chunk number 20: 
###################################################
#line 433 "OLIN.Rnw"
 
 mxy.plot(maM(norm.oslin),Ngc=maNgc(norm.oslin),Ngr=maNgr(norm.oslin),
                Nsc=maNsc(norm.oslin),Nsr=maNsr(norm.oslin),main="OSLIN")


###################################################
### chunk number 21:  eval=FALSE
###################################################
## #line 489 "OLIN.Rnw"
## 
## 
## data(sw.olin)
## 
## # DISTRIBUTION OF LOGGED RATIOS BEFORE BETWEEN-ARRAY-SCALING
## col <- c("red","blue","green","orange")
## M <- maM(sw.olin)
## 
## 
## plot(density(M[,4]),col=col[4],xlim=c(-2,2))
## for (i in 1:3){
##   lines(density(M[,i]),col=col[i])
## }
## 
## 
## # BETWEEN-ARRAY SCALING   
## sw.olin.s <- bas(sw.olin,mode="var")
##   
## 
## # VISUALISATION 
## M <- maM(sw.olin.s)
## plot(density(M[,4]),col=col[4],xlim=c(-2,2))
## for (i in 1:3){
##   lines(density(M[,i]),col=col[i])
## }
## 
## 


###################################################
### chunk number 22: 
###################################################
#line 524 "OLIN.Rnw"
data(sw.olin)
par(cex.main =0.8)
par(cex.lab=0.8)
col <- c("red","blue","green","orange")
M <- maM(sw.olin)
plot(density(M[,4]),col=col[4],xlim=c(-2,2))
for (i in 1:3){
  lines(density(M[,i]),col=col[i])
}


###################################################
### chunk number 23: 
###################################################
#line 542 "OLIN.Rnw"
sw.olin.s <- bas(sw.olin,mode="var")
par(cex.main = 0.8)
par(cex.lab = 0.8)
M <- maM(sw.olin.s)
plot(density(M[,4]),col=col[4],xlim=c(-2,2))
for (i in 1:3){
  lines(density(M[,i]),col=col[i])
}



###################################################
### chunk number 24: 
###################################################
#line 585 "OLIN.Rnw"
 A <- maA(sw[,3])
 M <- maM(sw[,3])
# Averaging
 Mav <- ma.vector(A,M,av="median",delta=50)
# Correlation 
 cor(Mav,M,use="pairwise.complete.obs")


###################################################
### chunk number 25: 
###################################################
#line 596 "OLIN.Rnw"
# From Vector to Matrix
 MM <-  v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw),visu=FALSE)
# Averaging of matrix M 
 MMav <- ma.matrix(MM,av="median",delta= 2,edgeNA=FALSE)
# Backconversion to vector
 Mav <- m2v(MMav,Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw),visu=FALSE)
# Correlation 
 cor(Mav,M,use="pairwise.complete.obs")


###################################################
### chunk number 26: 
###################################################
#line 619 "OLIN.Rnw"
 print(anovaint(sw,index=3,N=10))


###################################################
### chunk number 27: 
###################################################
#line 623 "OLIN.Rnw"
 data(sw.olin)
 print(anovaint(sw.olin,index=3,N=10))


###################################################
### chunk number 28:  eval=FALSE
###################################################
## #line 639 "OLIN.Rnw"
##   anovaspatial(sw,index=3,xN=8,yN=8,visu=TRUE)


###################################################
### chunk number 29:  eval=FALSE
###################################################
## #line 643 "OLIN.Rnw"
##   anovaspatial(sw.olin,index=3,xN=8,yN=8,visu=TRUE) 


###################################################
### chunk number 30: 
###################################################
#line 649 "OLIN.Rnw"
s <-  anovaspatial(sw,index=3,xN=8,yN=8,visu=TRUE)


###################################################
### chunk number 31: 
###################################################
#line 658 "OLIN.Rnw"
s <- anovaspatial(sw.olin,index=3,xN=8,yN=8,visu=TRUE) 


###################################################
### chunk number 32: 
###################################################
#line 676 "OLIN.Rnw"
 print(anovapin(sw.olin,index=3))


###################################################
### chunk number 33: 
###################################################
#line 681 "OLIN.Rnw"
 print(anovaplate(sw.olin,index=3))


###################################################
### chunk number 34:  eval=FALSE
###################################################
## #line 719 "OLIN.Rnw"
## FDR <- fdr.int(maA(sw)[,3],maM(sw)[,3],delta=50,N=10,av="median")
## sigint.plot(maA(sw)[,3],maM(sw)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### chunk number 35: 
###################################################
#line 728 "OLIN.Rnw"
FDR <- fdr.int(maA(sw)[,3],maM(sw)[,3],delta=50,N=10,av="median")
sigint.plot(maA(sw)[,3],maM(sw)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### chunk number 36:  eval=FALSE
###################################################
## #line 738 "OLIN.Rnw"
## data(sw.olin)
## FDR <- fdr.int(maA(sw.olin)[,3],maM(sw.olin)[,3],delta=50,N=10,av="median")
## sigint.plot(maA(sw.olin)[,3],maM(sw.olin)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### chunk number 37: 
###################################################
#line 748 "OLIN.Rnw"
data(sw.olin)
FDR <- fdr.int(maA(sw.olin)[,3],maM(sw.olin)[,3],delta=50,N=10,av="median")
sigint.plot(maA(sw.olin)[,3],maM(sw.olin)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### chunk number 38:  eval=FALSE
###################################################
## #line 765 "OLIN.Rnw"
## M <- v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
##                 Nsc=maNsc(sw),Nsr=maNsr(sw),main="MXY plot of SW-array 1")
## 
## FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
## sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### chunk number 39: 
###################################################
#line 778 "OLIN.Rnw"
M <- v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
                Nsc=maNsc(sw),Nsr=maNsr(sw),main="MXY plot of SW-array 1")

FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### chunk number 40:  eval=FALSE
###################################################
## #line 790 "OLIN.Rnw"
## M<- v2m(maM(sw.olin)[,3],Ngc=maNgc(sw.olin),Ngr=maNgr(sw.olin),
##                 Nsc=maNsc(sw.olin),Nsr=maNsr(sw.olin),main="MXY plot of SW-array 1")
## FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
## sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### chunk number 41: 
###################################################
#line 800 "OLIN.Rnw"
M<- v2m(maM(sw.olin)[,3],Ngc=maNgc(sw.olin),Ngr=maNgr(sw.olin),
                Nsc=maNsc(sw.olin),Nsr=maNsr(sw.olin),main="MXY plot of SW-array 1")
FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")

==> OLIN_1.74.1.tgz: OLIN/doc/OLIN.R <==
### R code from vignette source 'OLIN.Rnw'

###################################################
### code chunk number 1: OLIN.Rnw:55-56
###################################################
  library(OLIN) 


###################################################
### code chunk number 2: OLIN.Rnw:90-92 (eval = FALSE)
###################################################
##   data(sw)
##   fgbg.visu(sw[,3])


###################################################
### code chunk number 3: OLIN.Rnw:97-99
###################################################
  data(sw)
  fgbg.visu(sw[,3])


###################################################
### code chunk number 4: OLIN.Rnw:114-115 (eval = FALSE)
###################################################
## plot(maA(sw[,3]),maM(sw[,3]),xlab="A",ylab="M")


###################################################
### code chunk number 5: OLIN.Rnw:121-123
###################################################
par(cex.lab=0.6)
plot(maA(sw[,3]),maM(sw[,3]),xlab="A",ylab="M",pch='.')


###################################################
### code chunk number 6: OLIN.Rnw:131-133 (eval = FALSE)
###################################################
## mxy.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
##                  Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### code chunk number 7: OLIN.Rnw:139-141
###################################################
mxy.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
                 Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### code chunk number 8: OLIN.Rnw:154-156 (eval = FALSE)
###################################################
## data(sw.xy)
## mxy.abs.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### code chunk number 9: OLIN.Rnw:162-165
###################################################
data(sw.xy)
mxy.abs.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))



###################################################
### code chunk number 10: OLIN.Rnw:181-185 (eval = FALSE)
###################################################
## data(sw.xy)
## mxy2.plot(maM(sw)[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],
##           Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))
## 


###################################################
### code chunk number 11: OLIN.Rnw:191-195
###################################################
data(sw.xy)
mxy2.plot(maM(sw)[,3],X=sw.xy$X[,3],sw.xy$Y[,3],
          Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))



###################################################
### code chunk number 12: OLIN.Rnw:304-305
###################################################
norm.olin <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3])


###################################################
### code chunk number 13: OLIN.Rnw:316-321 (eval = FALSE)
###################################################
## plot(maA(norm.olin),maM(norm.olin),main="OLIN",pch=".")
## 
## mxy.plot(maM(norm.olin),Ngc=maNgc(norm.olin),Ngr=maNgr(norm.olin),
##                 Nsc=maNsc(norm.olin),Nsr=maNsr(norm.olin),main="OLIN")
## 


###################################################
### code chunk number 14: OLIN.Rnw:329-332
###################################################
par(cex.main=0.8)
par(cex.lab =0.8)
plot(maA(norm.olin),maM(norm.olin),main="OLIN",pch=".")


###################################################
### code chunk number 15: OLIN.Rnw:343-346
###################################################
 
mxy.plot(norm.olin,Ngc=maNgc(norm.olin),Ngr=maNgr(norm.olin),
                Nsc=maNsc(norm.olin),Nsr=maNsr(norm.olin),main="OLIN")


###################################################
### code chunk number 16: OLIN.Rnw:358-364 (eval = FALSE)
###################################################
## norm.olin.1 <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## norm.olin.2 <- olin(norm.olin.1,X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## norm.olin.3 <- olin(norm.olin.2,X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## 
## M <- cbind(maM(sw)[,3],maM(norm.olin.1),maM(norm.olin.2),maM(norm.olin.3))
## pairs(M,labels= c("raw","1.Iter.","2.Iter.","3.Iter."))


###################################################
### code chunk number 17: OLIN.Rnw:386-387
###################################################
norm.oslin <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],alpha=c(0.1,1,0.1),OSLIN=TRUE)


###################################################
### code chunk number 18: OLIN.Rnw:397-402 (eval = FALSE)
###################################################
## plot(maA(norm.oslin),maM(norm.oslin),main="OSLIN",pch=".")
## 
## mxy.plot(norm.oslin,Ngc=maNgc(norm.oslin),Ngr=maNgr(norm.oslin),
##                 Nsc=maNsc(norm.oslin),Nsr=maNsr(norm.oslin),main="OSLIN")
## 


###################################################
### code chunk number 19: OLIN.Rnw:410-413
###################################################
par(cex.main=0.8)
par(cex.lab =0.8)
plot(maA(norm.oslin),maM(norm.oslin),main="OSLIN",pch=".")


###################################################
### code chunk number 20: OLIN.Rnw:434-437
###################################################
 
 mxy.plot(norm.oslin,Ngc=maNgc(norm.oslin),Ngr=maNgr(norm.oslin),
                Nsc=maNsc(norm.oslin),Nsr=maNsr(norm.oslin),main="OSLIN")


###################################################
### code chunk number 21: OLIN.Rnw:490-517 (eval = FALSE)
###################################################
## 
## 
## data(sw.olin)
## 
## # DISTRIBUTION OF LOGGED RATIOS BEFORE BETWEEN-ARRAY-SCALING
## col <- c("red","blue","green","orange")
## M <- maM(sw.olin)
## 
## 
## plot(density(M[,4]),col=col[4],xlim=c(-2,2))
## for (i in 1:3){
##   lines(density(M[,i]),col=col[i])
## }
## 
## 
## # BETWEEN-ARRAY SCALING   
## sw.olin.s <- bas(sw.olin,mode="var")
##   
## 
## # VISUALISATION 
## M <- maM(sw.olin.s)
## plot(density(M[,4]),col=col[4],xlim=c(-2,2))
## for (i in 1:3){
##   lines(density(M[,i]),col=col[i])
## }
## 
## 


###################################################
### code chunk number 22: OLIN.Rnw:525-534
###################################################
data(sw.olin)
par(cex.main =0.8)
par(cex.lab=0.8)
col <- c("red","blue","green","orange")
M <- maM(sw.olin)
plot(density(M[,4]),col=col[4],xlim=c(-2,2))
for (i in 1:3){
  lines(density(M[,i]),col=col[i])
}


###################################################
### code chunk number 23: OLIN.Rnw:543-552
###################################################
sw.olin.s <- bas(sw.olin,mode="var")
par(cex.main = 0.8)
par(cex.lab = 0.8)
M <- maM(sw.olin.s)
plot(density(M[,4]),col=col[4],xlim=c(-2,2))
for (i in 1:3){
  lines(density(M[,i]),col=col[i])
}



###################################################
### code chunk number 24: OLIN.Rnw:586-592
###################################################
 A <- maA(sw[,3])
 M <- maM(sw[,3])
# Averaging
 Mav <- ma.vector(A,M,av="median",delta=50)
# Correlation 
 cor(Mav,M,use="pairwise.complete.obs")


###################################################
### code chunk number 25: OLIN.Rnw:597-605
###################################################
# From Vector to Matrix
 MM <-  v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw),visu=FALSE)
# Averaging of matrix M 
 MMav <- ma.matrix(MM,av="median",delta= 2,edgeNA=FALSE)
# Backconversion to vector
 Mav <- m2v(MMav,Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw),visu=FALSE)
# Correlation 
 cor(Mav,M,use="pairwise.complete.obs")


###################################################
### code chunk number 26: OLIN.Rnw:620-621
###################################################
 print(anovaint(sw,index=3,N=10))


###################################################
### code chunk number 27: OLIN.Rnw:624-626
###################################################
 data(sw.olin)
 print(anovaint(sw.olin,index=3,N=10))


###################################################
### code chunk number 28: OLIN.Rnw:640-641 (eval = FALSE)
###################################################
##   anovaspatial(sw,index=3,xN=8,yN=8,visu=TRUE)


###################################################
### code chunk number 29: OLIN.Rnw:644-645 (eval = FALSE)
###################################################
##   anovaspatial(sw.olin,index=3,xN=8,yN=8,visu=TRUE) 


###################################################
### code chunk number 30: OLIN.Rnw:650-651
###################################################
s <-  anovaspatial(sw,index=3,xN=8,yN=8,visu=TRUE)


###################################################
### code chunk number 31: OLIN.Rnw:659-660
###################################################
s <- anovaspatial(sw.olin,index=3,xN=8,yN=8,visu=TRUE) 


###################################################
### code chunk number 32: OLIN.Rnw:677-678
###################################################
 print(anovapin(sw.olin,index=3))


###################################################
### code chunk number 33: OLIN.Rnw:682-683
###################################################
 print(anovaplate(sw.olin,index=3))


###################################################
### code chunk number 34: OLIN.Rnw:720-722 (eval = FALSE)
###################################################
## FDR <- fdr.int(maA(sw)[,3],maM(sw)[,3],delta=50,N=10,av="median")
## sigint.plot(maA(sw)[,3],maM(sw)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### code chunk number 35: OLIN.Rnw:729-731
###################################################
FDR <- fdr.int(maA(sw)[,3],maM(sw)[,3],delta=50,N=10,av="median")
sigint.plot(maA(sw)[,3],maM(sw)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### code chunk number 36: OLIN.Rnw:739-742 (eval = FALSE)
###################################################
## data(sw.olin)
## FDR <- fdr.int(maA(sw.olin)[,3],maM(sw.olin)[,3],delta=50,N=10,av="median")
## sigint.plot(maA(sw.olin)[,3],maM(sw.olin)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### code chunk number 37: OLIN.Rnw:749-752
###################################################
data(sw.olin)
FDR <- fdr.int(maA(sw.olin)[,3],maM(sw.olin)[,3],delta=50,N=10,av="median")
sigint.plot(maA(sw.olin)[,3],maM(sw.olin)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### code chunk number 38: OLIN.Rnw:766-771 (eval = FALSE)
###################################################
## M <- v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
##                 Nsc=maNsc(sw),Nsr=maNsr(sw),main="MXY plot of SW-array 1")
## 
## FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
## sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### code chunk number 39: OLIN.Rnw:779-784
###################################################
M <- v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
                Nsc=maNsc(sw),Nsr=maNsr(sw),main="MXY plot of SW-array 1")

FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### code chunk number 40: OLIN.Rnw:791-795 (eval = FALSE)
###################################################
## M<- v2m(maM(sw.olin)[,3],Ngc=maNgc(sw.olin),Ngr=maNgr(sw.olin),
##                 Nsc=maNsc(sw.olin),Nsr=maNsr(sw.olin),main="MXY plot of SW-array 1")
## FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
## sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### code chunk number 41: OLIN.Rnw:801-805
###################################################
M<- v2m(maM(sw.olin)[,3],Ngc=maNgc(sw.olin),Ngr=maNgr(sw.olin),
                Nsc=maNsc(sw.olin),Nsr=maNsr(sw.olin),main="MXY plot of SW-array 1")
FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")
